covid-ru
--------

.. |pypi| image:: https://badge.fury.io/py/covid-ru.svg
   :target: https://badge.fury.io/py/covid-ru
.. |license| image:: https://img.shields.io/badge/License-MIT-yellow.svg?colorB=green
   :target: https://opensource.org/licenses/MIT
.. |pyversions| image:: https://img.shields.io/pypi/pyversions/covid-ru.svg?colorB=green
   :target: https://pypi.python.org/pypi/covid-ru
   
|pypi| |pyversions| |license|

Getting latest covid-19 stats in Russia to your cli from `стопкоронавирус.рф <https://стопкоронавирус.рф>`_

Synopsis
========

``covid-ru [--all|--dead|--tests|--cases|--recovered]``

Installation
============

``pip install covid-ru``

Description
===========

covid-ru is a small command-line tool that gets latest covid-19 in Russia stats.

Bugs
====

Bugs should be reported `here <https://github.com/strizhechenko/covid-ru/issues>`_.
